summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2017-09-03 21:16:01 +0100
committerCarl Hetherington <cth@carlh.net>2017-09-03 21:16:01 +0100
commit734faed493c1c824659714473d24917109120de4 (patch)
tree3b971a92ed3b7c4d4d96df13277037d14b4c786d /test
parenta2debda6473273338fd6f2c7936295eb387f9e72 (diff)
Add another test.
Diffstat (limited to 'test')
-rw-r--r--test/ffmpeg_audio_test.cc15
1 files changed, 14 insertions, 1 deletions
diff --git a/test/ffmpeg_audio_test.cc b/test/ffmpeg_audio_test.cc
index 7b77a7d8f..0aafb505f 100644
--- a/test/ffmpeg_audio_test.cc
+++ b/test/ffmpeg_audio_test.cc
@@ -126,7 +126,7 @@ BOOST_AUTO_TEST_CASE (ffmpeg_audio_test)
}
}
/** Decode a file containing truehd so we can profile it */
BOOST_AUTO_TEST_CASE (ffmpeg_audio_test2)
{
shared_ptr<Film> film = new_test_film2 ("ffmpeg_audio_test2");
@@ -137,3 +137,16 @@ BOOST_AUTO_TEST_CASE (ffmpeg_audio_test2)
shared_ptr<Player> player (new Player (film, film->playlist ()));
while (!player->pass ()) {}
}
+
+/** Decode a file containing truehd so we can profile it; this is with the player set to fast */
+BOOST_AUTO_TEST_CASE (ffmpeg_audio_test3)
+{
+ shared_ptr<Film> film = new_test_film2 ("ffmpeg_audio_test2");
+ shared_ptr<Content> content = content_factory(film, private_data / "wayne.mkv").front();
+ film->examine_and_add_content (content);
+ BOOST_REQUIRE (!wait_for_jobs ());
+
+ shared_ptr<Player> player (new Player (film, film->playlist ()));
+ player->set_fast ();
+ while (!player->pass ()) {}
+}
@@ -126,7 +126,7 @@ BOOST_AUTO_TEST_CASE (ffmpeg_audio_test)
}
}
-/** Decode a file containing truehd so we can profile it */
+/** Decode a file containing truehd so we can profile it; this is with the player set to normal */
BOOST_AUTO_TEST_CASE (ffmpeg_audio_test2)
{